>From d1e24443231b60ac60be7e6d9590fd55841300e4 Mon Sep 17 00:00:00 2001
From: Joseph Tulou <brezhoneg1@yahoo.fr>
Date: Fri, 9 Jan 2009 14:58:05 +0100
Subject: [PATCH] more straightforward access to still images (png, jpg, ....)
The two following syntaxes :
       vlc image.ext
       vlc fake://image.ext
are made equivalent to :
       vlc fake:// :fake-file=image.ext
---
 modules/access/fake.c |   36 +++++++++++++++++++++++++++++++++---
 1 files changed, 33 insertions(+), 3 deletions(-)

diff --git a/modules/access/fake.c b/modules/access/fake.c
index 2e0d990..6244f01 100644
--- a/modules/access/fake.c
+++ b/modules/access/fake.c
@@ -33,6 +33,7 @@
 #include <vlc_plugin.h>
 #include <vlc_access.h>
 #include <vlc_demux.h>
+#include <vlc_image.h>
 
 /*****************************************************************************
  * Module descriptior
@@ -70,7 +71,7 @@ vlc_module_begin ()
                  true );
 
     add_shortcut( "fake" )
-    set_capability( "access_demux", 0 )
+    set_capability( "access_demux", 100 )
     set_callbacks( Open, Close )
 vlc_module_end ()
 
@@ -97,10 +98,39 @@ static int Open( vlc_object_t *p_this )
     demux_sys_t *p_sys;
     es_format_t fmt;
 
-    /* Only when selected */
-    if( *p_demux->psz_access == '\0' )
+    /* if access is provided, it is expected to be fake */
+    if( *p_demux->psz_access != '\0' && strcmp( p_demux->psz_access, "fake" ) )
         return VLC_EGENERIC;
 
+   /**
+    * if path is provided, let's see if it could be an image
+    *   "vlc fake://image.ext" or "vlc image.ext" are made
+    *   equivalent to a "vlc fake:// :fake-file=image.ext"
+    *
+    **/
+    if( p_demux->psz_path && *p_demux->psz_path )
+    {
+        vlc_fourcc_t i_codec = image_Ext2Fourcc( p_demux->psz_path );
+        if( !i_codec )
+            return VLC_EGENERIC;
+    
+        char* p_codec = (char*) &i_codec;
+        msg_Dbg( p_demux, "still image detected with %c%c%c%c format",
+                   p_codec[0], p_codec[1], p_codec[2], p_codec[3] );
+    
+        vlc_object_t* p_input = p_demux->p_parent;
+        if( !p_input )
+            return VLC_EGENERIC;
+    
+        vlc_object_hold( p_input );
+    
+        /* set up fake-file on the fly */
+        var_Create( p_input, "fake-file", VLC_VAR_STRING );
+        var_SetString( p_input, "fake-file", p_demux->psz_path );
+    
+        vlc_object_release( p_input );
+    }
+    
     /* Set up p_demux */
     DEMUX_INIT_COMMON(); p_sys = p_demux->p_sys;
     p_demux->info.i_update = 0;
-- 
1.5.2.5

